@@ -42,9 +42,21 @@ class CustomHashingMethodCache(FileSystemCache):
         super().__init__(*args, hash_method=hashlib.sha256, **kwargs)
 
 
+class CustomDefaultHashingMethodCache(FileSystemCache):
+    _default_hash_method = hashlib.sha256
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+
 @pytest.fixture(
     autouse=True,
-    params=[FileSystemCache, CustomSerializerCache, CustomHashingMethodCache],
+    params=[
+        FileSystemCache,
+        CustomSerializerCache,
+        CustomHashingMethodCache,
+        CustomDefaultHashingMethodCache,
+    ],
 )
 def cache_factory(request, tmpdir):
     def _factory(self, *args, **kwargs):
